import 'dart:async';
import 'dart:ffi';

import 'package:flutter/services.dart';
import 'package:flutter_payone/Constants.dart';

class FlutterPayone {
  static const MethodChannel _channel = const MethodChannel('flutter_payone');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static String getCountryCode(Country name) {
    switch (name) {
      case Country.lao:
        return "LA";
      case Country.thai:
        return "TH";
    }
    return "not found";
  }
  static String getProvinceCode(Province name){
    switch(name){
      case Province.vientiane: 
        return "VTE";
      case Province.luangphabang: 
        return "LPB";
    }
     return "not found";
  }
  static String getCurrencyCode(Currency name){
    switch(name){
      case Currency.laoKip: 
        return "418";
      case Currency.thaiBaht: 
        return "123";
    }
     return "not found";
  }

  static Future<Void> initStore(
      String mcid,
      String province,
      String subscribeKey,
      String terminalid,
      String country,
      String bankName,
      String applicationId) async {
    String response = "";
    var storeData = <String, dynamic>{
      'mcid': mcid,
      // 'province': PayOneDataHelper.getProvinceCode(Province.vientiane),
      'province': province,
      'subscribeKey': subscribeKey,
      'terminalid': terminalid,
      'country': country,
      'iin': bankName,
      'applicationid': applicationId
    };

    try {
      final result = await _channel.invokeMethod('initStore', storeData);
      response = result.toString();
      print(response);
    } on PlatformException catch (e) {
      print("Failed to Invoke: '${e.message}'.");
    }
  }

  static Future<String> buildQrcode(
      int amount, String currency, String description) async {
    String response = "";

    var stringParams = <String, dynamic>{
      'amount': amount.toString(),
      'currency': currency,
      'invoiceid': '#comet' + DateTime.now().microsecondsSinceEpoch.toString(),
      'description': description
    };

    try {
      final result = await _channel.invokeMethod('buildqrcode', stringParams);
      response = result.toString();
      return response;
    } on PlatformException catch (e) {
      return "Failed to Invoke: '${e.message}'.";
    }
  }

  static Future<String> startObserve() async {
    try {
      final result = await _channel.invokeMethod('observe');
      String response = result.toString();
      return response;
    } on PlatformException catch (e) {
      return "Failed to Invoke: '${e.message}'.";
    }
  }
}
